import unittest

from intellij.discover import any_instance
from sqlalchemy import create_engine

from test.register import register

register()
any_instance().noisy = True


class TestDialect(unittest.TestCase):
    def test_simple(self):
        engine = create_engine('dg://identifier.sqlite')
        with engine.connect() as c:
            res = c.execute("select 'mama' union select 'papa'")
            print(list(res))
            res.close()


if __name__ == '__main__':
    unittest.main()



from sqlalchemy.testing.requirements import SuiteRequirements

from sqlalchemy.testing import exclusions


class Requirements(SuiteRequirements):
    def __init__(self):
        pass

    @property
    def order_by_col_from_union(self):
        return exclusions.closed()

    @property
    def cross_schema_fk_reflection(self):
        return exclusions.closed()

    @property
    def table_reflection(self):
        return exclusions.closed()

    @property
    def returning(self):
        return exclusions.open()



from sqlalchemy.connectors import Connector


class DGAPIConnector(Connector):
    driver = 'dgapi'

    supports_sane_rowcount_returning = False
    supports_sane_multi_rowcount = False

    supports_unicode_statements = True
    supports_unicode_binds = True

    supports_native_decimal = True
    default_paramstyle = 'qmark'

    def __init__(self, **kw):
        super(DGAPIConnector, self).__init__(**kw)

    @classmethod
    def dbapi(cls):
        import intellij.dgapi as module
        return module

    def create_connect_args(self, url):
        c_str = str(url)
        c_str = c_str[c_str.index("://") + 3:]
        return [[], {"dsn": c_str}]

    def is_disconnect(self, e, connection, cursor):
        if isinstance(e, self.dbapi.ProgrammingError):
            return "The cursor's connection has been closed." in str(e) or \
                   'Attempt to use a closed connection.' in str(e)
        else:
            return False



from setuptools import setup

setup(
    name='dg-alchemy-integration',
    version='0.0.1',
    author='Alexander Kass',
    description='Implementation of SQLAlchemy API for DataGrip connection',
    license='MIT',
    packages=['intellij', 'intellij.alchemy'],
    install_requires=[
        'dg-integration', 'sqlalchemy'
    ],
    keywords='IntelliJ IDEA DataGrip PhpStorm PyCharm GoLand',
    entry_points={
        'sqlalchemy.dialects': [
            'dg = intellij.alchemy.dgapi:DefaultDialect_dgapi',
        ]
    }
)
